@@ -36,9 +36,13 @@ DEBUG = True
 TEMPLATE_DEBUG = DEBUG
 
 TEST_DIR_PATH = os.path.join(BASE_DIR, 'tests', 'boilerplate', "TestHtml")
+ERROR_DIR_PATH = os.path.join(BASE_DIR, 'tests', 'boilerplate', "BackupHtml")
 
 if not os.path.exists(TEST_DIR_PATH):
     os.mkdir(TEST_DIR_PATH)
+    
+if not os.path.exists(ERROR_DIR_PATH):
+    os.mkdir(ERROR_DIR_PATH)
 
 DATABASES = {
     'default': {
