@@ -19,6 +19,7 @@ import os
 import re
 import hashlib
 import json
+import traceback
 
 from lxml import etree
 from lxml.html import soupparser
@@ -188,6 +189,8 @@ class Command(BaseCommand):
             logger.info('ALL OK!')
         except Exception as e:
             logger.error("build_boilerplate2 error:%s" % e)
+            with open('./AllError.log', 'w+') as log:
+                log.write(traceback.format_exc())
             raise
             
     #---------------------------------Main--------------------------------------
@@ -225,14 +228,27 @@ class Command(BaseCommand):
             placeholderId = "%s-%s-%d" % (filename, ele.tag, i)
             tagDict[ele.tag] = i + 1
             
-            if ele.tag in BLOCK_TAGS:
-                self.buildBlockTagPlaceholder(ele, placeholderId)
-            elif ele.tag in ALL_INSIDE_TAGS:
-                self.buildInsidePlaceholder(ele, placeholderId)
-            elif ele.tag in ALL_OUTSIDE_TAGS:
-                self.buildOutsidePlaceholder(ele, placeholderId)
+            if not ele.tag == 'p':
+                if ele.tag in BLOCK_TAGS:
+                    self.buildBlockTagPlaceholder(ele, placeholderId)
+                elif ele.tag in ALL_INSIDE_TAGS:
+                    self.buildInsidePlaceholder(ele, placeholderId)
+                elif ele.tag in ALL_OUTSIDE_TAGS:
+                    self.buildOutsidePlaceholder(ele, placeholderId)
+                else:
+                    pass
             else:
-                pass
+                dealWithOutSide = True
+                for name, value in ele.items():
+                    if 'boilerplateMark' == name:
+                        continue
+                    else:
+                        dealWithOutSide = False
+
+                if dealWithOutSide:
+                    self.buildOutsidePlaceholder(ele, placeholderId)
+                else:
+                    self.buildInsidePlaceholder(ele, placeholderId)
 
         for ele in eTree.iter():
             if 'Comment' in str(ele.tag):
@@ -322,9 +338,10 @@ class Command(BaseCommand):
             ele.text = ''
 
         if ele.tag == 'p':
-            ele.set('cmsboilerplatetag', 'p')
-            comment = etree.Comment('cmsboilerplatetag=p')
-            ele.addnext(comment)
+            commentStart = etree.Comment('cmsboilerplatetagstart=p')
+            ele.addprevious(commentStart)
+            commentEnd = etree.Comment('cmsboilerplatetagend=p')
+            ele.addnext(commentEnd)
 
         if ele.getchildren():
             if ele[-1].tail is None:
